==> haskell-hspec-megaparsec-2.0.0-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 2.0.0
id: hspec-megaparsec-2.0.0-BPJCarLdLBuFfR3egftj8T
key: hspec-megaparsec-2.0.0-BPJCarLdLBuFfR3egftj8T
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 8c1fa6eb17460d8ebb80f3509bca0c8f
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-megaparsec-2.0.0
hs-libraries: HShspec-megaparsec-2.0.0-BPJCarLdLBuFfR3egftj8T
depends:
    base-4.12.0.0 containers-0.6.0.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-2.0.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 2.0.1
id: hspec-megaparsec-2.0.1-DdzfKdVGGfKERwjxsWkT7a
key: hspec-megaparsec-2.0.1-DdzfKdVGGfKERwjxsWkT7a
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 154a50acfce715e5142ee18bb41abf35
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-megaparsec-2.0.1
hs-libraries: HShspec-megaparsec-2.0.1-DdzfKdVGGfKERwjxsWkT7a
depends:
    base-4.12.0.0 containers-0.6.0.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    megaparsec-7.0.5-7nNPtHGYzPNBh8epow1r1w
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
